<!-- gros_client_py_markdown documentation master file, created by
sphinx-quickstart on Mon Sep 11 17:56:50 2023.
You can adapt this file completely to your liking, but it should at least
contain the root `toctree` directive. -->

# Welcome to gros_client_py_markdown’s documentation!

# Contents:

* [conf module](conf.md)
  * [`setup()`](conf.md#conf.setup)
  * [`skip()`](conf.md#conf.skip)
* [markdown_conf module](markdown_conf.md)
  * [`setup()`](markdown_conf.md#markdown_conf.setup)
  * [`skip()`](markdown_conf.md#markdown_conf.skip)
* [setup module](setup.md)
* [src package](src.md)
  * [Subpackages](src.md#subpackages)
    * [src.gros_client package](src.gros_client.md)
      * [Subpackages](src.gros_client.md#subpackages)
      * [Module contents](src.gros_client.md#module-src.gros_client)
  * [Module contents](src.md#module-src)
* [test package](test.md)
  * [Submodules](test.md#submodules)
  * [test.test_car module](test.md#test-test-car-module)
  * [test.test_human module](test.md#module-test.test_human)
    * [`TestHuman`](test.md#test.test_human.TestHuman)
      * [`TestHuman.test_disable_debug_state()`](test.md#test.test_human.TestHuman.test_disable_debug_state)
      * [`TestHuman.test_enable_debug_state()`](test.md#test.test_human.TestHuman.test_enable_debug_state)
      * [`TestHuman.test_get_joint_limit()`](test.md#test.test_human.TestHuman.test_get_joint_limit)
      * [`TestHuman.test_get_joint_states()`](test.md#test.test_human.TestHuman.test_get_joint_states)
      * [`TestHuman.test_get_video_status()`](test.md#test.test_human.TestHuman.test_get_video_status)
      * [`TestHuman.test_get_video_stream_url()`](test.md#test.test_human.TestHuman.test_get_video_stream_url)
      * [`TestHuman.test_head()`](test.md#test.test_human.TestHuman.test_head)
      * [`TestHuman.test_move()`](test.md#test.test_human.TestHuman.test_move)
      * [`TestHuman.test_stand()`](test.md#test.test_human.TestHuman.test_stand)
      * [`TestHuman.test_start()`](test.md#test.test_human.TestHuman.test_start)
      * [`TestHuman.test_stop()`](test.md#test.test_human.TestHuman.test_stop)
    * [`on_close()`](test.md#test.test_human.on_close)
    * [`on_error()`](test.md#test.test_human.on_error)
    * [`on_message()`](test.md#test.test_human.on_message)
    * [`on_open()`](test.md#test.test_human.on_open)
  * [Module contents](test.md#module-test)

# Indices and tables

* [Index](genindex.md)
* [Module Index](py-modindex.md)
* [Search Page](search.md)
